@@ -21,3 +21,8 @@ TIMER_DEFAULTS = {
 }
 
 COUNTDOWN_INCREMENTS = 1
+
+
+# Experimental Features
+
+RANDOM_FONTS = False
