@@ -2,16 +2,20 @@ from colorama import Fore, Style
 import sys
 import logging
 from sylo.models import Durations
-from pyfiglet import figlet_format
+from sylo.definitions import RANDOM_FONTS
+from pyfiglet import figlet_format, FigletFont
+from random import sample
 logger = logging.getLogger(__name__)
 
 
 def print_message(message: str, timer_val: int = None):
     logger.debug(f'Printing message: {message} with a timer_val of {timer_val}')
     if message == "work_start":
-        print(f"{Fore.RED}WORK{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} minutes")
+        print(f"""{Fore.BLUE}Ctrl-C to stop timer early{Style.RESET_ALL}
+{Fore.RED}WORK{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} minutes""")
     elif message == "rest_start":
-        print(f"{Fore.GREEN}REST{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} minutes")
+        print(f"""{Fore.BLUE}Ctrl-C to stop timer early{Style.RESET_ALL}
+{Fore.GREEN}REST{Style.RESET_ALL} for {Fore.YELLOW}{timer_val}{Style.RESET_ALL} minutes""")
     elif message == "summary_and_quit":
         sys.stdout.write("\033[K")
         print(
@@ -54,7 +58,11 @@ def ascii_header(font: str):
     return figlet_format('Sort Your Life Out', font=font, width=40)
 
 
-def print_header_small(double: bool, font: str):
+def print_header_small(double: bool):
+    if RANDOM_FONTS is True:
+        font = random_ascii_header()
+    else:
+        font = ascii_header_small(font='alligator')
     if double is True:
         color = Fore.BLUE
         double_message = '>>>>>>>>>>>> DOUBLE SPEED MODE >>>>>>>>>>>>'
@@ -62,8 +70,20 @@ def print_header_small(double: bool, font: str):
         color = Fore.RED
         double_message = ''
     print(f"{double_message}")
-    print(f"""{color}{ascii_header_small(font)}{Style.RESET_ALL}""")
+    print(f"""{color}{font}{Style.RESET_ALL}""")
 
 
 def ascii_header_small(font: str):
     return figlet_format('SYLO', font=font, width=60)
+
+
+def random_ascii_header():
+    fonts = FigletFont.getFonts()
+    random_fonts = sample(fonts, int(len(fonts)/2))
+    for f in random_fonts:
+        try:
+            logger.debug(f'Output of shuffled fonts: {f}')
+            return figlet_format('SYLO', font=f, width=40)
+        except Exception as e:
+            logger.debug(f'Output of shuffled fonts: {f} {e}')
+            pass
